function Tmix = Remix_split(  stream  , frac , Tfrac , Trest )
% Calculates T after mixing two stream fractions at different Ts
% Arguments: stream = streams matrix, 1st column T [K], 2nd column qs [e.g.,kW]
%                     starting at q=0 and q-sorted; qs > 0: cold , qs < 0: hot .
%                     If just two rows stream is assumed constant mCp.
%            frac   = flowrate fraction of stream at Tfrac  []
%            Tfrac  = T of stream fraction    frac          [K]
%            Trest  = T of stream fraction ( 1 - frac )     [K]
%                     [Note: kW are used as an alias for any thermal flow unit.]
% Returns  : Tmix   = Outlet T of mixed stream              [K]

% Copyright (c) Fidel Mato & UVa 2018
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Heat integration, Heat exchanger


Ts       = stream( : , 1 )      ;                          % [K]
Hs       = stream( : , 2 )      ;                          % [kW]
Hfracs   = stream( : , 2 )*frac ;                          % [kW]
Hrests   = Hs .- Hfracs         ;                          % [kW]

Hfrac    = interp1( Ts , Hfracs , Tfrac ) ;                % [kW]
Hrest    = interp1( Ts , Hrests , Trest ) ;                % [kW]

Tmix     =  interp1( Hs , Ts , ( Hfrac + Hrest) ) ;        % [kW]


return ;

end
% -------------------------------------------------------------------------------- __END__
