function sts = TsdHs_to_strs( TsdHs )
% Transforms a stream in [Ts dHs] format to a matrix of hix format streams [ T1 T2 dH 0 ].
%
% Argument : TsdHs = stream matrix, 1st column T [K], 2nd column qs [e.g.,kW]
%                    starting at q=0 and q-sorted; qs > 0: cold , qs < 0: hot .
%                    # If just two rows stream is assumed constant mCp. TODO
% Returns  : strs  = matrix containing a stream [ T1 T2 dH 0 ] for every Tn-Tn+1 interval.

% Copyright (c) Fidel Mato & UVa 2019
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Heat integration

% [Note: kW are used as an alias for any thermal flow unit; and K for any T unit]

incT     = 1e-3                     ;                      % [K]
sts      = []                       ;
nsts     = length( TsdHs( : , 1 ) ) ;                      % []
for( k = 2 : nsts ) ;
    st   = [ TsdHs( k - 1 , 1 ) , TsdHs( k , 1 ) , TsdHs( k , 2 ) - TsdHs( k - 1 , 2 ) ] ;
    sts  = [ sts ; [ st , 0 ] ] ;
end

for( i = 1 : nsts - 1 )
    if ( sts(i,1) == sts(i,2) )                                       % flat stream
      if ( sts(i,3) >=0 )
        sts(i,2) = sts(i,2)+incT;
      else
        sts(i,1) = sts(i,1)+incT;
      end
    end
    if ( (sts(i,3)==0) && (sts(i,4) == 0) )
       fprintf("Null stream: %6.1f %6.1f %10.2f %10.4f\n\n", sts(i,:));
       return                                                       % ending in error
    elseif ( (sts(i,3)==0) )                             % & (sts(i,4) ~= 0) )
        sts(i,3)=sts(i,4)*(sts(i,2)-sts(i,1));                   % Calculating dH from mCp 
    else
        sts(i,4)=sts(i,3)/(sts(i,2)-sts(i,1));                          % or vice versa
    end
    if ( sts(i,4) < 0 )
       fprintf('Odd stream: %6.1f %6.1f %10.2f %10.4f\n\n', sts(i,:) );
       return                                                       % ending in error
    end
end


return ;

end
% -------------------------------------------------------------------------------- __END__
