function [ Tis dHis ] = compenth( st )
% Calculates compound enthalpies by Temperature intervals
% (c) Fidel Mato & UVa , 2017

  [ ns , ignore ] = size( st ) ;                           % ns: Number of Streams
  % sorting + eliminating repeated :
  Tis  = sort( unique( [ st( : , 1 ) ; st( : , 2 ) ] ) , 'descend' ) ;
  ni   = length( Tis ) - 1 ;                               % Number of intervals
  dHis = zeros( ni , 1 ) ;                                 % Interval enthalpies, init
  for( i = 1 : ni )

      Thigh = Tis( i )     ;
      Tlow  = Tis( i + 1 ) ;
      sumCp = 0            ;                               % summation of mCp
      for( k = 1 : ns )
          
          T1  = st( k , 1 ) ;
          T2  = st( k , 2 ) ;
          mCp = st( k , 3 ) ;
          if( T1 > T2 )                                    % Hot
              if( T1 >= Thigh && T2 <= Tlow )
                  sumCp = sumCp + mCp ;
              end
          else                                             % Cold
              if( T1 <= Tlow && T2 >= Thigh )
                  sumCp = sumCp - mCp ;
              end
          end
      
      end
      dHis( i ) = ( Thigh - Tlow )*sumCp ;
  
  end

end
% ================================================================================ __END__
