function [ dH avmCp ] = stream_dH_from_Ts( stream , stmfrac , T1 , T2 )
% Calculates HX from T vs. q stream curves
% Arguments: stream     = stream matrix, 1st column T [K], 2nd column qs [e.g.,kW]
%                             starting at q=0 and q-sorted; qs > 0: cold , qs < 0: hot .
%                             If just two rows stream is assumed constant mCp.
%            stmfrac    = flowrate fraction of stream involved in this HX [] .
%            T1 , T2    = from , to temperatures [K] .
% Returns  : [ dH avmCp ]
%            dH         = enthalpy flow from T1 to T2 [kW] .
%            avmCp      = average (apparent) mCp [kW/K] .

% Copyright (c) Fidel Mato & UVa 2018
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Heat integration, Heat exchanger

% [Note: kW are used as an alias for any thermal flow unit and K for any T unit.]

H1       = interp1( stream( : , 1 ) , stream( : , 2 ) , T1 ) ; % [kW]
H2       = interp1( stream( : , 1 ) , stream( : , 2 ) , T2 ) ; % [kW]
dH       = H2 - H1                                           ; % [kW]
avmCp    = dH/( T2 - T1 )                                    ; % [kW/K]

return ;

end
% -------------------------------------------------------------------------------- __END__
