function [Hid_CO2] = AL_Hid_CO2 (T)
% AL_Hid_CO2 - Enthalpy calculation using Aly-Lee Equation
% Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
% Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
% Just for CO2
% call: [T] = [K]
% return: Hid_CO2 = [J/mol/K]


% ----------------------------------------------------------------------------- Parameters
% From Aly&Lee_1981 Table 1, p 174

% --------------------------- CO2 (273.15-1500 K)
A_CO2  = -7460.81     *  4.184 ;                                     % [J/mol]
B_CO2  =     7.54056  *  4.184 ;                                     % [J/mol/K]
C_CO2  =     7.51625  *  4.184 ;                                     % [J/mol/K]
D_CO2  =  1442.70              ;                                     % [K]
E_CO2  =     5.38023  *  4.184 ;                                     % [J/mol/K]
F_CO2  =   647.502             ;                                     % [K]
G_CO2  =     6.25230  *  4.184 ;                                     % [J/mol/K]

A = A_CO2 ; B = B_CO2 ; C = C_CO2 ; D = D_CO2 ; E = E_CO2 ; F = F_CO2 ; G = G_CO2 ;

% T = 100  ;                                                         % [K]

Hid_CO2 = B*T + C*T*(D/T)*coth(D/T) - E*T*(F/T)*tanh(F/T) + A ;      % [J/mol]
                       
return  ;

