function AL_Hid_fg = AL_Hid_fg( T , x_O2 , x_N2 , x_CO2 , x_H2O )
%
% AL_Hid_fg - Flue gases (O2,N2,CO2,H2O) ideal enthalpy using Aly&Lee equation.
%
%   Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
%   Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
%
%   call  : AL_Hid_fg( T , x_O2 , x_N2 , x_CO2 , x_H2O )
%                where [ T ] = [K] and all compositions = [mole f.]
%   return: Hid_fg in [J/mol]

AL_Hid_fg = 0 ;                                           % [J/mol] init

if( x_O2 > 0 )
    AL_Hid_fg = AL_Hid_fg + x_O2*AL_Hid_O2( T ) ;   % [J/mol] 
end

if( x_N2 > 0 )
    AL_Hid_fg = AL_Hid_fg + x_N2*AL_Hid_N2( T ) ;   % [J/mol] 
end

if( x_CO2 > 0 )
    AL_Hid_fg = AL_Hid_fg + x_CO2*AL_Hid_CO2( T ) ; % [J/mol] 
end

if( x_H2O > 0 )
    AL_Hid_fg = AL_Hid_fg + x_H2O*AL_Hid_H2O( T ) ; % [J/mol] 
end

return ;
