function Sres = SRK_Sres( T , params , Z )
% Calculates Soave-Redlich-Kwong residual entropy.
% Arguments: T      = [K]
%            params = (see function SRK_mix_parameters( T , P , ... ) )  
%                     matrix containing SRK mixture parameters 
%                        [ Amix 0     ...    0             []
%                          Bmix 0     ...    0             []
%                          Dmix 0     ...    0             []
%                          amix 0     ...    0             [bar*L^2/mol^2]
%                          bmix 0     ...    0             [L/mol]
%                          B1   B2    ...    Bn            [] 
%                          A11  A12   ...    A1n           [] cross coefficients
%                          A21  A22   ...    A2n           [] cross coefficients
%                          ...  ...   ...    ...           [] cross coefficients
%                          An1  An2   ...    Ann  ]        [] cross coefficients            Z      = mixture compressibility factor       [] 
%            Z      = Compressibility factor []
% Returns  : Sres   = Residual entropy       [J/mol/K]

% Copyright (c) Fidel Mato & UVa 2016
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Partial fugacity coefficient, Cubic EOS , Soave Redlich Kwong

R        = 8.314459848     ;                               % [J/mol/K]

Amix     = params( 1 , 1 ) ;                               % []
Bmix     = params( 2 , 1 ) ;                               % []
Dmix     = params( 3 , 1 ) ;                               % [bar*L/mol/K]
amix     = params( 4 , 1 ) ;                               % [bar*L/mol/K]

Sres     = R*( -log( Z - Bmix ) + Amix*Dmix/amix/Bmix*log( 1 + Bmix/Z ) ) ; % [J/mol/K]

end
% -------------------------------------------------------------------------------- __END__
