function Hres = SRK_1C_Hres( Z , T , P , Tc , Pc , w , alpha_function )
% Calculates residual enthalpy for P , T using the Soave-Redlich-Kwong EoS
% Arguments: (  Z , T , P , Tc , Pc , w , alpha_function ) = 
%                         [ dimless , K , bar , K , bar , dimless , string ]
%                         alpha_function: string defining the alpha function type to use


% Returns  : Hres = [ J/mol ]
% Returns  : Hres                     = [ kJ/mol ]


R           = 8.314459848 ;                                % [J/mol/K]

Tr          = T/Tc                   ;                     % [dimless]
Pr          = P/Pc                   ;                     % [dimless]
[ alpha m ] = SRK_1C_alpha( alpha_function , Tr , w ) ;    % [dimless]
Pc          = Pc*1e5                 ;                     % [bar=>Pa]
ac          = 0.427480*R^2*Tc^2/Pc   ;                     % [J*m^3/mol^2]
a           = alpha*ac               ;                     % [J*m^3/mol^2]
A           = 0.42748*alpha*Pr/Tr^2  ;                     % [dimless]
B           = 0.08664*Pr/Tr          ;                     % [dimless]

D        = m*a*sqrt( Tr/alpha )                           ; % [J*m^3/mol^2]
Hres     = R*T*( 1 - Z + A/B*( 1 + D/a )*log( 1 + B/Z ) ) ; % [J/mol]

end
