function Hres = VDW_1C_Hres( Z , T , P , Tc , Pc )
% Calculates residual enthalpy for P , T using the van der Waals EoS
% Arguments: (  Z , T , P , Tc , Pc ) = [ dimless , K , bar , K , bar ]
% Returns  : Hres                     = [ J/mol ]

R        = 0.08314459848 ;                                 % [bar*L/mol/K]

a        = 27*R^2*Tc^2/64/Pc ;                             % [bar*L^2/mol^2]
b        = R*Tc/8/Pc         ;                             % [L/mol]

V        = Z*R*T/P           ;                             % [L/mol]

Hres     = R*T*( 2*a/R/T/V - b/( V - b ) )*1e2 ;           % [J/mol]

end
