function [ phase Z1 Z2 ] = VDW_1C_phase_Z( T , P , Tc , Pc )
% Calculates phase and compressiblilty factor of a pure compound
% for T , P using the van der Waals EoS
% Arguments: ( T , P , Tc , Pc ) = [ K , bar , K , bar ]
% Returns  : [ phase Z1 Z2 ] , [ string , dimless , dimless ]
%            phase can be: 'V' , 'L' or 'V+L'
%            Z1 , Z2 : equal if 1 phase , or Z1 = Zv , Z2 = Zl if at saturation

[ Zv Zl ] = VDW_1C_compress_factors( T , P , Tc , Pc ) ;   % [dimless]

if     ( isreal( Zv ) && ~isreal( Zl ) )
    
    phase = 'V' ;
    Z1    = Zv  ;                                          % [dimless]
    Z2    = Zv  ;                                          % [dimless]
    return ;
    
elseif ( ~isreal( Zv ) && isreal( Zl ) )
    
    phase = 'L' ;
    Z1    = Zl  ;                                          % [dimless]
    Z2    = Zl  ;                                          % [dimless]
    return ;
    
elseif ( isreal( Zv ) && isreal( Zl ) )
    
    Psat = VDW_1C_Psat( T , Tc , Pc ) ;                    % [bar]
    
    if   ( abs( P - Psat) <= 1e-6 )                        % [bar]
        
        phase = 'L+V' ;
        Z1    = Zv  ;                                      % [dimless]
        Z2    = Zl  ;                                      % [dimless]
        return ;
        
    elseif( P < Psat )
        
        phase = 'V' ;
        Z1    = Zv  ;                                      % [dimless]
        Z2    = Zv  ;                                      % [dimless]
        return ;
        
    elseif( P > Psat )
        
        phase = 'L' ;
        Z1    = Zl  ;                                      % [dimless]
        Z2    = Zl  ;                                      % [dimless]
        return ;
        
    end
    
end

end



