function dH12id = dHid_Polynomial_3( T1 , T2 , params )
% Calculates the ideal enthalpy change between T1 and T2 using
% a 3dr order polynomial correlation for the ideal heat capacity:
%     Cp = A + B*T + C*T^2 + D*T^3 , Cp = [J/mol/K] , T = [K]
% Arguments: ( T1 , T2 , ...   = [ K , K , ... ]
%              params        ) = [ A B C D ] to yield Cp in J/mol/K 
% Returns  : dH12id            = [ J/mol ]

A        = params( 1 ) ;
B        = params( 2 ) ;
C        = params( 3 ) ;
D        = params( 4 ) ;

dH12id   =  A*( T2 - T1 ) + B/2*( T2^2 - T1^2 ) + ...
                C/3*( T2^3 - T1^3 ) + D/4*( T2^4 - T1^4 ) ;  % [J/mol]

end
