function dH12id = Hid_Shomate( T1 , T2 , Shomate_params )
% Calculates the ideal enthalpy change between T1 and T2 using the Shomate equation.
% Gas Phase standard enthalpy (Shomate) NIST :
% H° − H°298.15= A*t + B*t^2/2 + C*t^3/3 + D*t^4/4 − E/t + F − H , where
%                        H° = standard enthalpy (kJ/mol) , t = temperature (K) / 1000
% Arguments: ( T1 , T2 , Shomate_params ) = [ dimless , dimless , ... ]
%                        Shomate_params : [ A B C D E ] to yield H in kJ/mol/K 
% Returns  : dH12      = [ kJ/mol ]

A        = Shomate_params( 1 ) ;
B        = Shomate_params( 2 ) ;
C        = Shomate_params( 3 ) ;
D        = Shomate_params( 4 ) ;
E        = Shomate_params( 5 ) ;

t1       = T1/1000 ;                                       % [K]
t2       = T2/1000 ;                                       % [K]

dH12id   =  A*( t2 - t1 ) + B/2*( t2^2 - t1^2 ) + C/3*( t2^3 - t1^3 ) + ...
                        D/4*( t2^4 - t1^4 ) -   E*( 1/t2 - 1/t1 ) ;  % [kJ/mol]

end
