function dH12id = dHid_Shomate_from_Cp( T1 , T2 , Shomate_params )
% Calculates the ideal enthalpy change between T1 and T2 using the Shomate equation (Cp).
% Gas Phase Heat Capacity (Shomate Equation) NIST :
% Cp° = A + B*t + C*t^2 + D*t^3 + E/t^2 , (J/mol*K) , t = temperature (K) / 1000
% Arguments: ( T1 , T2 , Shomate_params ) = [ dimless , dimless , ... ]
%                        Shomate_params : [ A B C D E ] to yield Cp in J/mol/K 
% Returns  : dH12      = [ kJ/mol ]

% Beware units!

A        = Shomate_params( 1 ) ;
B        = Shomate_params( 2 ) ;
C        = Shomate_params( 3 ) ;
D        = Shomate_params( 4 ) ;
E        = Shomate_params( 5 ) ;

t1       = T1/1000 ;                                       % [K]
t2       = T2/1000 ;                                       % [K]

% Cp1 =  A + B*t1 + C*t1^2 + D*t1^3 + E/t1^2    % [J/mol/K]
% Cp2 =  A + B*t2 + C*t2^2 + D*t2^3 + E/t2^2    % [J/mol/K]
                  
dH12id   =  A*( t2 - t1 ) + B/2*( t2^2 - t1^2 ) + C/3*( t2^3 - t1^3 ) + ...
                        D/4*( t2^4 - t1^4 ) -   E*( 1/t2 - 1/t1 )         ;  % [kJ/mol]

end
