function dS12id = dSid_Shomate( T1 , P1 , T2 , P2 , Shomate_params )
% Calculates the ideal entropy change between T1 , P1 and T2 , P2
% using the Shomate equation for the thermal change.
% Gas Phase standard entropy (Shomate) NIST :
% S° = A*ln(t) + B*t + C*t^2/2 + D*t^3/3 - E/(2*t^2) + G, where
%                        S° = standard entropy (J/mol*K), t = temperature (K)/1000
% (Shomate parameters F , G and H are not needed for calculating entropy changes)
%
% Arguments: ( T1 , P1 , T2 , P2 ...   = [ K , bar , K , bar ]
%                   , Shomate_params ) = [ to yield S in J/mol/K ]
% Returns  : dS12id                    = [ J/mol/K ]

R        = 8.314459848 ;                                   % [J/mol/K]

A        = Shomate_params( 1 ) ;
B        = Shomate_params( 2 ) ;
C        = Shomate_params( 3 ) ;
D        = Shomate_params( 4 ) ;
E        = Shomate_params( 5 ) ;

t1       = T1/1000 ;                                       % [K]
t2       = T2/1000 ;                                       % [K]

dS12id   =  A*log( t2/t1 ) + B*( t2 - t1 ) + C/2*( t2^2 - t1^2 ) ...
            + D/3*( t2^3 - t1^3 ) - E/2*( 1/t2^2 - 1/t1^2 ) ...
            - R*log( P2/P1 ) ;                             % [J/mol/K]

end
